@@ -41,6 +41,7 @@ var ENTITY_INSTANCE = {
     addEntityTypeString: 'Add driver\'s license',
     editEntityTypeString: 'Edit driver\'s license',
     deleteEntityTypeString: 'Delete driver\'s license',
+    supportsWalletStorage: false,
   },
   attributeInstances: [
     {
@@ -211,8 +212,10 @@ function updateCreditCardForCvc(updatedCvcValue) {
 function entityInstaceToEntityInstanceWithLabels(entityInstance, sublabel) {
   return ({
     guid: entityInstance.guid,
+    type: entityInstance.type,
     entityInstanceLabel: entityInstance.type.typeNameAsString,
     entityInstanceSubLabel: sublabel,
+    storedInWallet: false,
   });
 };
 
@@ -923,6 +926,7 @@ var availableTests = [
             addEntityTypeString: 'Add driver\'s license',
             editEntityTypeString: 'Edit driver\'s license',
             deleteEntityTypeString: 'Delete driver\'s license',
+            supportsWalletStorage: false,
           },
           attributeInstances: [
             {
@@ -972,6 +976,7 @@ var availableTests = [
             addEntityTypeString: 'Add passport',
             editEntityTypeString: 'Edit passport',
             deleteEntityTypeString: 'Delete passport',
+            supportsWalletStorage: false,
           },
           attributeInstances: [
             {
@@ -1012,6 +1017,7 @@ var availableTests = [
             addEntityTypeString: 'Add passport',
             editEntityTypeString: 'Edit passport',
             deleteEntityTypeString: 'Delete passport',
+            supportsWalletStorage: false,
           },
           attributeInstances: [
             {
@@ -1052,6 +1058,7 @@ var availableTests = [
             addEntityTypeString: 'Add passport',
             editEntityTypeString: 'Edit passport',
             deleteEntityTypeString: 'Delete passport',
+            supportsWalletStorage: false,
           },
           attributeInstances: [
             {
@@ -1102,6 +1109,7 @@ var availableTests = [
             addEntityTypeString: 'Add vehicle',
             editEntityTypeString: 'Edit vehicle',
             deleteEntityTypeString: 'Delete vehicle',
+            supportsWalletStorage: false,
           },
           attributeInstances: [
             {
@@ -1134,6 +1142,7 @@ var availableTests = [
             addEntityTypeString: 'Add vehicle',
             editEntityTypeString: 'Edit vehicle',
             deleteEntityTypeString: 'Delete vehicle',
+            supportsWalletStorage: false,
           },
           attributeInstances: [
             {
@@ -1274,8 +1283,9 @@ var availableTests = [
     chrome.test.succeed();
   },
 
-  async function getAllEntityTypes() {
-    const entityTypesList = await chrome.autofillPrivate.getAllEntityTypes();
+  async function getWritableEntityTypes() {
+    const entityTypesList =
+        await chrome.autofillPrivate.getWritableEntityTypes();
     const expectedEntityTypesList = [
       {
         typeName: 0,
@@ -1283,6 +1293,7 @@ var availableTests = [
         addEntityTypeString: 'Add passport',
         editEntityTypeString: 'Edit passport',
         deleteEntityTypeString: 'Delete passport',
+        supportsWalletStorage: false,
       },
       {
         typeName: 1,
@@ -1290,6 +1301,7 @@ var availableTests = [
         addEntityTypeString: 'Add driver\'s license',
         editEntityTypeString: 'Edit driver\'s license',
         deleteEntityTypeString: 'Delete driver\'s license',
+        supportsWalletStorage: false,
       },
       {
         typeName: 2,
@@ -1297,6 +1309,63 @@ var availableTests = [
         addEntityTypeString: 'Add vehicle',
         editEntityTypeString: 'Edit vehicle',
         deleteEntityTypeString: 'Delete vehicle',
+        supportsWalletStorage: false,
+      },
+    ];
+    for (const index in expectedEntityTypesList) {
+      chrome.test.assertEq(
+          expectedEntityTypesList[index], entityTypesList[index]);
+    }
+    chrome.test.succeed();
+  },
+
+  async function verifyWritableEntityTypesDoesNotIncludeReadOnlyTypes() {
+    const entityTypesList =
+        await chrome.autofillPrivate.getWritableEntityTypes();
+    for (const index in entityTypesList) {
+      chrome.test.assertFalse(
+          entityTypesList[index].typeName === 6);  // Flight reservation
+    }
+    chrome.test.succeed();
+  },
+
+  async function verifyWritableEntityTypesWithSyncOnReturnsWalletEntityTypes() {
+    const entityTypesList =
+        await chrome.autofillPrivate.getWritableEntityTypes();
+    const expectedEntityTypesList = [
+      {
+        typeName: 0,
+        typeNameAsString: 'Passport',
+        addEntityTypeString: 'Add passport',
+        editEntityTypeString: 'Edit passport',
+        deleteEntityTypeString: 'Delete passport',
+        supportsWalletStorage: false,
+      },
+      {
+        typeName: 1,
+        typeNameAsString: 'Driver\'s license',
+        addEntityTypeString: 'Add driver\'s license',
+        editEntityTypeString: 'Edit driver\'s license',
+        deleteEntityTypeString: 'Delete driver\'s license',
+        supportsWalletStorage: false,
+      },
+      {
+        typeName: 2,
+        typeNameAsString: 'Vehicle',
+        addEntityTypeString: 'Add vehicle',
+        editEntityTypeString: 'Edit vehicle',
+        deleteEntityTypeString: 'Delete vehicle',
+        supportsWalletStorage:
+            true,  // If a type can be both local and server stored,
+                   // server stored type takes precedence.
+      },
+      {
+        typeName: 6,
+        typeNameAsString: 'Flight',
+        addEntityTypeString: '',
+        editEntityTypeString: '',
+        deleteEntityTypeString: '',
+        supportsWalletStorage: true,
       },
     ];
     for (const index in expectedEntityTypesList) {
@@ -1369,6 +1438,29 @@ var availableTests = [
         false, await chrome.autofillPrivate.getAutofillAiOptInStatus());
     chrome.test.succeed();
   },
+
+  async function testEntityTypeInEntityInstanceWithLabels() {
+    // Add an entity to ensure there is something to load.
+    await new Promise(resolve => {
+      chrome.test.listenOnce(
+          chrome.autofillPrivate.onEntityInstancesChanged, resolve);
+      chrome.autofillPrivate.addOrUpdateEntityInstance(ENTITY_INSTANCE);
+    });
+
+    const entityInstancesWithLabelsList =
+        await chrome.autofillPrivate.loadEntityInstances();
+    chrome.test.assertEq(1, entityInstancesWithLabelsList.length);
+    const entityInstanceWithLabels = entityInstancesWithLabelsList[0];
+
+    chrome.test.assertTrue(
+        !!entityInstanceWithLabels.type,
+        'EntityInstanceWithLabels should have a type property');
+    chrome.test.assertEq(
+        ENTITY_INSTANCE.type, entityInstanceWithLabels.type,
+        'The type property should match the entity type');
+
+    chrome.test.succeed();
+  },
 ];
 
 /** @const */
@@ -1421,10 +1513,16 @@ var TESTS_FOR_CONFIG = {
   'loadFirstEntityInstance': ['loadFirstEntityInstance'],
   'loadUpdatedEntityInstance': ['loadUpdatedEntityInstance'],
   'getEntityInstanceByGuid': ['getEntityInstanceByGuid'],
-  'getAllEntityTypes': ['getAllEntityTypes'],
+  'getWritableEntityTypes': ['getWritableEntityTypes'],
+  'verifyWritableEntityTypesDoesNotIncludeReadOnlyTypes':
+      ['verifyWritableEntityTypesDoesNotIncludeReadOnlyTypes'],
+  'verifyWritableEntityTypesWithSyncOnReturnsWalletEntityTypes':
+      ['verifyWritableEntityTypesWithSyncOnReturnsWalletEntityTypes'],
   'getAllAttributeTypesForEntityTypeName':
       ['getAllAttributeTypesForEntityTypeName'],
   'testExpectedLabelsAreGenerated': ['testExpectedLabelsAreGenerated'],
+  'testEntityTypeInEntityInstanceWithLabels':
+      ['testEntityTypeInEntityInstanceWithLabels'],
   'getEmptyPayOverTimeIssuerList': ['getEmptyPayOverTimeIssuerList'],
   'optIntoAutofillAi': ['optIntoAutofillAi'],
   'optOutOfAutofillAi': ['optOutOfAutofillAi'],
