@@ -12,7 +12,7 @@
 //     --gtest_filter=CommandsApiTest.SynthesizedCommand
 
 // Called when the user clicks on the browser action.
-chrome.browserAction.onClicked.addListener(function(windowId) {
+chrome.action.onClicked.addListener(function () {
 });
 
 chrome.commands.getAll(function(commands) {
@@ -20,14 +20,14 @@ chrome.commands.getAll(function(commands) {
 
   // A browser actions gets a synthesized command with no shortcut and no
   // description.
-  chrome.test.assertEq("_execute_browser_action", commands[0].name);
+  chrome.test.assertEq("_execute_action", commands[0].name);
   chrome.test.assertEq("",                        commands[0].description);
   chrome.test.assertEq("",                        commands[0].shortcut);
 
   // This one on the other hand, has it all.
   chrome.test.assertEq("unrelated-feature",       commands[1].name);
   chrome.test.assertEq("Toggle feature foo",      commands[1].description);
-  if (window.navigator.platform == "MacIntel") {
+  if (navigator.platform == "MacIntel") {
     chrome.test.assertEq("⌃⇧Y",                   commands[1].shortcut);
   } else {
     chrome.test.assertEq("Ctrl+Shift+Y",          commands[1].shortcut);
