@@ -3,8 +3,13 @@
 // found in the LICENSE file.
 
 // Called when the user clicks on the browser action.
-chrome.action.onClicked.addListener(function (windowId) {
-  chrome.tabs.executeScript(null, { code: "document.body.bgColor='red'" });
+chrome.action.onClicked.addListener(function (tab) {
+  chrome.scripting.executeScript({
+    target: { tabId: tab.id },
+    func: () => {
+      document.body.bgColor = 'red';
+    }
+  });
 });
 
 chrome.test.notifyPass();
