@@ -130,7 +130,7 @@ suite('Personalization app controller', () => {
       id: '9bd1d7a3-f995-4445-be47-53c5b58ce1cb',
       dedupKey: '2d0d1595-14af-4471-b2db-b9c8eae3a491',
       name: 'foo',
-      date: {data: []},
+      date: '',
       url: {url: 'foo.com'},
       location: 'home',
     }];
@@ -956,7 +956,7 @@ suite('does not respond to re-selecting the current wallpaper', () => {
           id: '9bd1d7a3-f995-4445-be47-53c5b58ce1cb',
           dedupKey: dedupKey === undefined ? null : dedupKey,
           name: 'foo',
-          date: {data: []},
+          date: '',
           url: {url: 'foo.com'},
           location: 'home',
         };
@@ -1098,7 +1098,7 @@ suite('daily refresh loading', () => {
         id: 'google-photos-photo-0',
         dedupKey: 'google-photos-photo-0',
         name: 'photo 0',
-        date: {data: []},
+        date: '',
         url: {url: ''},
         location: 'home',
       },
@@ -1106,7 +1106,7 @@ suite('daily refresh loading', () => {
         id: 'google-photos-photo-1',
         dedupKey: 'google-photos-photo-1',
         name: 'photo 1',
-        date: {data: []},
+        date: '',
         url: {url: ''},
         location: 'home',
       },
