@@ -2,14 +2,13 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import {stringToMojoString16} from 'chrome://resources/js/mojo_type_util.js';
 import type {AutocompleteResult} from 'chrome://resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
 import {assertEquals} from 'chrome://webui-test/chai_assert.js';
 
 export function createAutocompleteResult(
     modifiers: Partial<AutocompleteResult> = {}): AutocompleteResult {
   const base: AutocompleteResult = {
-    input: stringToMojoString16(''),
+    input: '',
     matches: [],
     suggestionGroupsMap: {},
     smartComposeInlineHint: null,
