@@ -26,6 +26,7 @@ class FakePageHandler extends TestBrowserProxy implements PageHandlerInterface {
     super([
       'deleteAutocompleteMatch',
       'activateKeyword',
+      'showContextMenu',
       'executeAction',
       'onNavigationLikely',
       'onThumbnailRemoved',
@@ -74,6 +75,10 @@ class FakePageHandler extends TestBrowserProxy implements PageHandlerInterface {
     });
   }
 
+  showContextMenu(point: {x: number, y: number}) {
+    this.methodCalled('showContextMenu', {point});
+  }
+
   executeAction(
       line: number, actionIndex: number, url: Url,
       matchSelectionTimestamp: TimeTicks, mouseButton: number, altKey: boolean,
