@@ -3,6 +3,7 @@
 // found in the LICENSE file.
 
 export interface PageElementTypes {
+  actuationOnWebSwitch: HTMLInputElement;
   content: HTMLElement;
   status: HTMLElement;
   pageHeader: HTMLElement;
@@ -76,6 +77,8 @@ export interface PageElementTypes {
   desktopScreenshotImg: HTMLImageElement;
   desktopScreenshotErrorReason: HTMLSpanElement;
   panelScreenshot: HTMLButtonElement;
+  captureRegionBtn: HTMLButtonElement;
+  captureRegionResultList: HTMLUListElement;
   createTabInBackground: HTMLInputElement;
   canAttachCheckbox: HTMLInputElement;
   scrollToDocumentId: HTMLSpanElement;
@@ -123,6 +126,10 @@ export interface PageElementTypes {
   stopActorTask: HTMLButtonElement;
   actorTaskId: HTMLInputElement;
   executeAction: HTMLButtonElement;
+  credentialSelection: HTMLDivElement;
+  selectCredential: HTMLSelectElement;
+  credentialOnce: HTMLButtonElement;
+  credentialAlways: HTMLButtonElement;
   actionProtoEncodedText: HTMLInputElement;
   actionStatus: HTMLSpanElement;
   actionUpdatedContextResult: HTMLSpanElement;
@@ -156,6 +163,8 @@ export interface PageElementTypes {
   switchConversationBtn: HTMLButtonElement;
   registerConversationBtn: HTMLButtonElement;
   conversationId: HTMLInputElement;
+  textmode: HTMLInputElement;
+  audiomode: HTMLInputElement;
 }
 
 export const $: PageElementTypes = new Proxy({}, {
