@@ -5,7 +5,6 @@
 // clang-format off
 import 'chrome://settings/settings.js';
 
-import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {CrInputElement, CrTextareaElement} from 'chrome://settings/lazy_load.js';
 import {AutofillAddressOptInChange, AutofillManagerImpl, CountryDetailManagerProxyImpl} from 'chrome://settings/lazy_load.js';
@@ -13,7 +12,7 @@ import {assertEquals, assertFalse, assertGT, assertTrue} from 'chrome://webui-te
 import type {MetricsTracker} from 'chrome://webui-test/metrics_test_support.js';
 import {fakeMetricsPrivate} from 'chrome://webui-test/metrics_test_support.js';
 import type {CrLinkRowElement} from 'chrome://settings/settings.js';
-import {OpenWindowProxyImpl} from 'chrome://settings/settings.js';
+import {loadTimeData, OpenWindowProxyImpl} from 'chrome://settings/settings.js';
 import {eventToPromise, whenAttributeIs, isVisible} from 'chrome://webui-test/test_util.js';
 import {flushTasks} from 'chrome://webui-test/polymer_test_util.js';
 import {TestOpenWindowProxy} from 'chrome://webui-test/test_open_window_proxy.js';
@@ -184,7 +183,7 @@ suite('AutofillSectionUiTest', function() {
       const expectedMessage =
           loadTimeData.getString('removeSyncAddressConfirmationDescription');
       assertEquals(
-          dialog.$.description.textContent!.trim(), expectedMessage,
+          dialog.$.description.textContent.trim(), expectedMessage,
           'Sync-on message should be visible');
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
@@ -209,7 +208,7 @@ suite('AutofillSectionUiTest', function() {
       const expectedMessage =
           loadTimeData.getString('removeLocalAddressConfirmationDescription');
       assertEquals(
-          dialog.$.description.textContent!.trim(), expectedMessage,
+          dialog.$.description.textContent.trim(), expectedMessage,
           'Sync-off message should be visible');
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
@@ -226,7 +225,7 @@ suite('AutofillSectionUiTest', function() {
       const expectedMessage =
           loadTimeData.getString('removeLocalAddressConfirmationDescription');
       assertEquals(
-          dialog.$.description.textContent!.trim(), expectedMessage,
+          dialog.$.description.textContent.trim(), expectedMessage,
           'Sync-off message should be visible when account info is missing');
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
@@ -245,7 +244,7 @@ suite('AutofillSectionUiTest', function() {
       const expectedMessage = loadTimeData.getStringF(
           'deleteAccountAddressRecordTypeNotice', STUB_USER_ACCOUNT_INFO.email);
       assertEquals(
-          dialog.$.description.textContent!.trim(), expectedMessage,
+          dialog.$.description.textContent.trim(), expectedMessage,
           'Account address message should be visible');
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
@@ -526,7 +525,7 @@ suite('AutofillSectionAddressTests', function() {
     // Eliminate white space between nodes!
     const addressPieces = row.querySelector('#addressSummary')!.children;
     for (const addressPiece of addressPieces) {
-      actualSummary += addressPiece.textContent!.trim();
+      actualSummary += addressPiece.textContent.trim();
     }
 
     assertEquals(addressSummary, actualSummary);
@@ -572,6 +571,33 @@ suite('AutofillSectionAddressTests', function() {
     document.body.removeChild(section);
   });
 
+  test('verifyNoAddressLocalIndicationForAccountNameEmail', async () => {
+    const nameEmailAddress = createAddressEntry();
+    nameEmailAddress.metadata!.recordType =
+        chrome.autofillPrivate.AddressRecordType.ACCOUNT_NAME_EMAIL;
+
+    const autofillManager = new TestAutofillManager();
+    autofillManager.data.addresses = [nameEmailAddress];
+    autofillManager.data.accountInfo = {
+      ...STUB_USER_ACCOUNT_INFO,
+    };
+    AutofillManagerImpl.setInstance(autofillManager);
+
+    const section = document.createElement('settings-autofill-section');
+    document.body.appendChild(section);
+    await autofillManager.whenCalled('getAddressList');
+    await flushTasks();
+
+    const addressList = section.$.addressList;
+    const getIcon = () => addressList.children[0]!.querySelector<HTMLElement>(
+        '#address-row-icon');
+    const iconName = getIcon()!.getAttribute('icon');
+    assertFalse(
+        !!iconName && iconName.includes('cloud-off'),
+        'Local indicator should not be shown on account name email profile');
+    document.body.removeChild(section);
+  });
+
   test('verifyAddressRowButtonTriggersDropdown', async function() {
     const address = createAddressEntry();
     const section = await createAutofillSection([address], {});
@@ -710,11 +736,26 @@ suite('AutofillSectionAddressTests', function() {
 
     assertTrue(removeAddressDialog.wasConfirmed());
     assertEquals(
-        1, metricsTracker.count('Autofill.ProfileDeleted.Settings', true));
+        1,
+        metricsTracker.count('Autofill.ProfileDeleted.Settings.Account', true));
     assertEquals(
-        0, metricsTracker.count('Autofill.ProfileDeleted.Settings', false));
-    assertEquals(1, metricsTracker.count('Autofill.ProfileDeleted.Any', true));
-    assertEquals(0, metricsTracker.count('Autofill.ProfileDeleted.Any', false));
+        0,
+        metricsTracker.count(
+            'Autofill.ProfileDeleted.Settings.Account', false));
+    assertEquals(
+        1,
+        metricsTracker.count('Autofill.ProfileDeleted.Settings.Total', true));
+    assertEquals(
+        0,
+        metricsTracker.count('Autofill.ProfileDeleted.Settings.Total', false));
+    assertEquals(
+        1, metricsTracker.count('Autofill.ProfileDeleted.Any.Account', true));
+    assertEquals(
+        0, metricsTracker.count('Autofill.ProfileDeleted.Any.Account', false));
+    assertEquals(
+        1, metricsTracker.count('Autofill.ProfileDeleted.Any.Total', true));
+    assertEquals(
+        0, metricsTracker.count('Autofill.ProfileDeleted.Any.Total', false));
 
     const expected = new AutofillManagerExpectations();
     expected.requestedAddresses = 1;
@@ -737,11 +778,26 @@ suite('AutofillSectionAddressTests', function() {
     await eventToPromise('close', removeAddressDialog);
     assertFalse(removeAddressDialog.wasConfirmed());
     assertEquals(
-        0, metricsTracker.count('Autofill.ProfileDeleted.Settings', true));
+        0,
+        metricsTracker.count('Autofill.ProfileDeleted.Settings.Account', true));
     assertEquals(
-        1, metricsTracker.count('Autofill.ProfileDeleted.Settings', false));
-    assertEquals(0, metricsTracker.count('Autofill.ProfileDeleted.Any', true));
-    assertEquals(1, metricsTracker.count('Autofill.ProfileDeleted.Any', false));
+        1,
+        metricsTracker.count(
+            'Autofill.ProfileDeleted.Settings.Account', false));
+    assertEquals(
+        0,
+        metricsTracker.count('Autofill.ProfileDeleted.Settings.Total', true));
+    assertEquals(
+        1,
+        metricsTracker.count('Autofill.ProfileDeleted.Settings.Total', false));
+    assertEquals(
+        0, metricsTracker.count('Autofill.ProfileDeleted.Any.Account', true));
+    assertEquals(
+        1, metricsTracker.count('Autofill.ProfileDeleted.Any.Account', false));
+    assertEquals(
+        0, metricsTracker.count('Autofill.ProfileDeleted.Any.Total', true));
+    assertEquals(
+        1, metricsTracker.count('Autofill.ProfileDeleted.Any.Total', false));
 
     const expected = new AutofillManagerExpectations();
     expected.requestedAddresses = 1;
@@ -1212,7 +1268,7 @@ suite('AutofillSectionAddressLocaleTests', function() {
       assertTrue(!!countrySelect);
       assertEquals(
           'United States',
-          countrySelect.selectedOptions[0]!.textContent!.trim());
+          countrySelect.selectedOptions[0]!.textContent.trim());
       index++;
       // Name
       row = rows[index]!;
@@ -1280,7 +1336,7 @@ suite('AutofillSectionAddressLocaleTests', function() {
       assertTrue(!!countrySelect);
       assertEquals(
           'United Kingdom',
-          countrySelect.selectedOptions[0]!.textContent!.trim());
+          countrySelect.selectedOptions[0]!.textContent.trim());
       index++;
       // Name
       row = rows[index]!;
@@ -1357,7 +1413,7 @@ suite('AutofillSectionAddressLocaleTests', function() {
       const countrySelect = row.querySelector('select');
       assertTrue(!!countrySelect);
       assertEquals(
-          'Israel', countrySelect.selectedOptions[0]!.textContent!.trim());
+          'Israel', countrySelect.selectedOptions[0]!.textContent.trim());
       index++;
       // Name
       row = rows[index]!;
@@ -1420,7 +1476,7 @@ suite('AutofillSectionAddressLocaleTests', function() {
       const countrySelect = row.querySelector('select');
       assertTrue(!!countrySelect);
       assertEquals(
-          'Israel', countrySelect.selectedOptions[0]!.textContent!.trim());
+          'Israel', countrySelect.selectedOptions[0]!.textContent.trim());
       index++;
       // Name
       row = rows[index]!;
