@@ -4,10 +4,9 @@
 
 import 'chrome://settings/settings.js';
 
-import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {CrActionMenuElement, SettingsSyncAccountControlElement, StoredAccount} from 'chrome://settings/settings.js';
-import {resetRouterForTesting, Router, SignedInState, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
+import {loadTimeData, resetRouterForTesting, Router, SignedInState, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
 import {assertEquals, assertFalse, assertNotEquals, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import {isChildVisible, isVisible} from 'chrome://webui-test/test_util.js';
 
@@ -126,10 +125,10 @@ suite('SyncAccountControl', function() {
     // Avatar row shows the right account.
     assertTrue(isChildVisible(testElement, '#promo-header'));
     assertTrue(isChildVisible(testElement, '#avatar-row'));
-    assertTrue(userInfo.textContent!.includes('fooName'));
-    assertTrue(userInfo.textContent!.includes('foo@foo.com'));
-    assertFalse(userInfo.textContent!.includes('barName'));
-    assertFalse(userInfo.textContent!.includes('bar@bar.com'));
+    assertTrue(userInfo.textContent.includes('fooName'));
+    assertTrue(userInfo.textContent.includes('foo@foo.com'));
+    assertFalse(userInfo.textContent.includes('barName'));
+    assertFalse(userInfo.textContent.includes('bar@bar.com'));
 
     // Menu contains the right items.
     assertTrue(!!testElement.shadowRoot!.querySelector('#menu'));
@@ -139,8 +138,8 @@ suite('SyncAccountControl', function() {
     const items =
         testElement.shadowRoot!.querySelectorAll<HTMLElement>('.dropdown-item');
     assertEquals(3, items.length);
-    assertTrue(items[0]!.textContent!.includes('foo@foo.com'));
-    assertTrue(items[1]!.textContent!.includes('bar@bar.com'));
+    assertTrue(items[0]!.textContent.includes('foo@foo.com'));
+    assertTrue(items[1]!.textContent.includes('bar@bar.com'));
     assertEquals(items[2]!.id, 'sign-in-item');
 
     // "sync to" button is showing the correct name and syncs with the
@@ -171,10 +170,10 @@ suite('SyncAccountControl', function() {
     // email.
     items[1]!.click();
     flush();
-    assertFalse(userInfo.textContent!.includes('fooName'));
-    assertFalse(userInfo.textContent!.includes('foo@foo.com'));
-    assertTrue(userInfo.textContent!.includes('barName'));
-    assertTrue(userInfo.textContent!.includes('bar@bar.com'));
+    assertFalse(userInfo.textContent.includes('fooName'));
+    assertFalse(userInfo.textContent.includes('foo@foo.com'));
+    assertTrue(userInfo.textContent.includes('barName'));
+    assertTrue(userInfo.textContent.includes('bar@bar.com'));
     assertTrue(isVisible(syncButton));
 
     browserProxy.resetResolver('startSyncingWithEmail');
@@ -283,10 +282,10 @@ suite('SyncAccountControl', function() {
 
     const userInfo =
         testElement.shadowRoot!.querySelector<HTMLElement>('#user-info')!;
-    assertTrue(userInfo.textContent!.includes('barName'));
-    assertTrue(userInfo.textContent!.includes('bar@bar.com'));
-    assertFalse(userInfo.textContent!.includes('fooName'));
-    assertFalse(userInfo.textContent!.includes('foo@foo.com'));
+    assertTrue(userInfo.textContent.includes('barName'));
+    assertTrue(userInfo.textContent.includes('bar@bar.com'));
+    assertFalse(userInfo.textContent.includes('fooName'));
+    assertFalse(userInfo.textContent.includes('foo@foo.com'));
 
     assertFalse(isChildVisible(testElement, '#sync-button'));
     assertTrue(isChildVisible(testElement, '#turn-off'));
@@ -323,7 +322,7 @@ suite('SyncAccountControl', function() {
             '[icon="settings:sync-problem"]'));
         const displayedText =
             userInfo.querySelector<HTMLElement>(
-                        'div:not([hidden])')!.textContent!;
+                        'div:not([hidden])')!.textContent;
         assertTrue(displayedText.includes('fooName'));
         assertTrue(isChildVisible(testElement, '#sync-error-button'));
         assertTrue(isChildVisible(testElement, '#turn-off'));
@@ -370,7 +369,7 @@ suite('SyncAccountControl', function() {
         const userInfo = testElement.shadowRoot!.querySelector('#user-info')!;
         const displayedText =
             userInfo.querySelector<HTMLElement>(
-                        'div:not([hidden])')!.textContent!;
+                        'div:not([hidden])')!.textContent;
 
         assertTrue(
             testElement.shadowRoot!
@@ -402,8 +401,8 @@ suite('SyncAccountControl', function() {
     const setupButtons =
         testElement.shadowRoot!.querySelector('#setup-buttons');
 
-    assertTrue(userInfo.textContent!.includes('barName'));
-    assertTrue(userInfo.textContent!.includes('Setup in progress...'));
+    assertTrue(userInfo.textContent.includes('barName'));
+    assertTrue(userInfo.textContent.includes('Setup in progress...'));
     assertTrue(isVisible(setupButtons));
   });
 
@@ -425,7 +424,7 @@ suite('SyncAccountControl', function() {
     const setupButtons =
         testElement.shadowRoot!.querySelector('#setup-buttons');
 
-    assertTrue(userInfo.textContent!.includes('Sign in again'));
+    assertTrue(userInfo.textContent.includes('Sign in again'));
     assertTrue(isVisible(setupButtons));
 
     // Other buttons are not shown, https://crbug.com/405980868
@@ -590,7 +589,7 @@ suite('SyncAccountControl', function() {
     assertTrue(isChildVisible(testElement, '#avatar-row'));
     const userInfo =
         testElement.shadowRoot!.querySelector<HTMLElement>('#user-info')!;
-    const secondaryContentSignedIn = userInfo.children[1]!.textContent!;
+    const secondaryContentSignedIn = userInfo.children[1]!.textContent;
     assertNotEquals(secondaryContentSignedIn.trim(), signedInAccount.email);
     assertFalse(isChildVisible(testElement, '#signin-paused-buttons'));
     assertFalse(isChildVisible(testElement, '#dropdown-arrow'));
@@ -603,7 +602,7 @@ suite('SyncAccountControl', function() {
     };
 
     assertTrue(isChildVisible(testElement, '#avatar-row'));
-    const secondaryContentSigninPaused = userInfo.children[1]!.textContent!;
+    const secondaryContentSigninPaused = userInfo.children[1]!.textContent;
     assertNotEquals(secondaryContentSignedIn, secondaryContentSigninPaused);
     assertEquals(secondaryContentSigninPaused.trim(), signedInAccount.email);
     assertTrue(isChildVisible(testElement, '#signin-paused-buttons'));
